@@ -1,19 +1,3 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (C) 2013-2017 Gauvain Pocentek <gauvain@pocentek.net>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Wrapper for the GitLab API."""
 
 import os
@@ -204,6 +188,8 @@ class Gitlab:
         """See :class:`~gitlab.v4.objects.PersonalAccessTokenManager`"""
         self.topics = objects.TopicManager(self)
         """See :class:`~gitlab.v4.objects.TopicManager`"""
+        self.statistics = objects.ApplicationStatisticsManager(self)
+        """See :class:`~gitlab.v4.objects.ApplicationStatisticsManager`"""
 
     def __enter__(self) -> "Gitlab":
         return self
@@ -371,7 +357,9 @@ class Gitlab:
         success.
         """
         self.user = self._objects.CurrentUserManager(self).get()
-        self._check_url(self.user.web_url, path=self.user.username)
+
+        if hasattr(self.user, "web_url") and hasattr(self.user, "username"):
+            self._check_url(self.user.web_url, path=self.user.username)
 
     def version(self) -> Tuple[str, str]:
         """Returns the version and revision of the gitlab server.
@@ -453,7 +441,7 @@ class Gitlab:
         return data["html"]
 
     @gitlab.exceptions.on_http_error(gitlab.exceptions.GitlabLicenseError)
-    def get_license(self, **kwargs: Any) -> Dict[str, Any]:
+    def get_license(self, **kwargs: Any) -> Dict[str, Union[str, Dict[str, str]]]:
         """Retrieve information about the current license.
 
         Args:
