@@ -1,8 +1,9 @@
 from typing import Any, cast, Dict, Optional, Union
 
 from gitlab import exceptions as exc
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import GetWithoutIdMixin, SaveMixin, UpdateMixin
+from gitlab.types import RequiredOptional
 
 __all__ = [
     "ApplicationAppearance",
@@ -37,7 +38,7 @@ class ApplicationAppearanceManager(GetWithoutIdMixin, UpdateMixin, RESTManager):
     def update(
         self,
         id: Optional[Union[str, int]] = None,
-        new_data: Dict[str, Any] = None,
+        new_data: Optional[Dict[str, Any]] = None,
         **kwargs: Any
     ) -> Dict[str, Any]:
         """Update an object on the server.
@@ -56,9 +57,7 @@ class ApplicationAppearanceManager(GetWithoutIdMixin, UpdateMixin, RESTManager):
         """
         new_data = new_data or {}
         data = new_data.copy()
-        return super(ApplicationAppearanceManager, self).update(id, data, **kwargs)
+        return super().update(id, data, **kwargs)
 
-    def get(
-        self, id: Optional[Union[int, str]] = None, **kwargs: Any
-    ) -> Optional[ApplicationAppearance]:
-        return cast(Optional[ApplicationAppearance], super().get(id=id, **kwargs))
+    def get(self, **kwargs: Any) -> ApplicationAppearance:
+        return cast(ApplicationAppearance, super().get(**kwargs))
