@@ -1,4 +1,4 @@
-from typing import Any, Callable, cast, Dict, Optional, TYPE_CHECKING, Union
+from typing import Any, Callable, cast, Dict, Iterator, Optional, TYPE_CHECKING, Union
 
 import requests
 
@@ -7,6 +7,7 @@ from gitlab import exceptions as exc
 from gitlab import utils
 from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import RefreshMixin, RetrieveMixin
+from gitlab.types import ArrayAttribute
 
 __all__ = [
     "ProjectJob",
@@ -27,8 +28,8 @@ class ProjectJob(RefreshMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabJobCancelError: If the job could not be canceled
         """
-        path = f"{self.manager.path}/{self.get_id()}/cancel"
-        result = self.manager.gitlab.http_post(path)
+        path = f"{self.manager.path}/{self.encoded_id}/cancel"
+        result = self.manager.gitlab.http_post(path, **kwargs)
         if TYPE_CHECKING:
             assert isinstance(result, dict)
         return result
@@ -45,8 +46,8 @@ class ProjectJob(RefreshMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabJobRetryError: If the job could not be retried
         """
-        path = f"{self.manager.path}/{self.get_id()}/retry"
-        result = self.manager.gitlab.http_post(path)
+        path = f"{self.manager.path}/{self.encoded_id}/retry"
+        result = self.manager.gitlab.http_post(path, **kwargs)
         if TYPE_CHECKING:
             assert isinstance(result, dict)
         return result
@@ -63,8 +64,8 @@ class ProjectJob(RefreshMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabJobPlayError: If the job could not be triggered
         """
-        path = f"{self.manager.path}/{self.get_id()}/play"
-        self.manager.gitlab.http_post(path)
+        path = f"{self.manager.path}/{self.encoded_id}/play"
+        self.manager.gitlab.http_post(path, **kwargs)
 
     @cli.register_custom_action("ProjectJob")
     @exc.on_http_error(exc.GitlabJobEraseError)
@@ -78,8 +79,8 @@ class ProjectJob(RefreshMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabJobEraseError: If the job could not be erased
         """
-        path = f"{self.manager.path}/{self.get_id()}/erase"
-        self.manager.gitlab.http_post(path)
+        path = f"{self.manager.path}/{self.encoded_id}/erase"
+        self.manager.gitlab.http_post(path, **kwargs)
 
     @cli.register_custom_action("ProjectJob")
     @exc.on_http_error(exc.GitlabCreateError)
@@ -93,8 +94,8 @@ class ProjectJob(RefreshMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabCreateError: If the request could not be performed
         """
-        path = f"{self.manager.path}/{self.get_id()}/artifacts/keep"
-        self.manager.gitlab.http_post(path)
+        path = f"{self.manager.path}/{self.encoded_id}/artifacts/keep"
+        self.manager.gitlab.http_post(path, **kwargs)
 
     @cli.register_custom_action("ProjectJob")
     @exc.on_http_error(exc.GitlabCreateError)
@@ -108,8 +109,8 @@ class ProjectJob(RefreshMixin, RESTObject):
             GitlabAuthenticationError: If authentication is not correct
             GitlabDeleteError: If the request could not be performed
         """
-        path = f"{self.manager.path}/{self.get_id()}/artifacts"
-        self.manager.gitlab.http_delete(path)
+        path = f"{self.manager.path}/{self.encoded_id}/artifacts"
+        self.manager.gitlab.http_delete(path, **kwargs)
 
     @cli.register_custom_action("ProjectJob")
     @exc.on_http_error(exc.GitlabGetError)
@@ -118,14 +119,18 @@ class ProjectJob(RefreshMixin, RESTObject):
         streamed: bool = False,
         action: Optional[Callable[..., Any]] = None,
         chunk_size: int = 1024,
+        *,
+        iterator: bool = False,
         **kwargs: Any,
-    ) -> Optional[bytes]:
+    ) -> Optional[Union[bytes, Iterator[Any]]]:
         """Get the job artifacts.
 
         Args:
             streamed: If True the data will be processed by chunks of
                 `chunk_size` and each chunk is passed to `action` for
                 treatment
+            iterator: If True directly return the underlying response
+                iterator
             action: Callable responsible of dealing with chunk of
                 data
             chunk_size: Size of each chunk
@@ -138,13 +143,15 @@ class ProjectJob(RefreshMixin, RESTObject):
         Returns:
             The artifacts if `streamed` is False, None otherwise.
         """
-        path = f"{self.manager.path}/{self.get_id()}/artifacts"
+        path = f"{self.manager.path}/{self.encoded_id}/artifacts"
         result = self.manager.gitlab.http_get(
             path, streamed=streamed, raw=True, **kwargs
         )
         if TYPE_CHECKING:
             assert isinstance(result, requests.Response)
-        return utils.response_content(result, streamed, action, chunk_size)
+        return utils.response_content(
+            result, streamed, action, chunk_size, iterator=iterator
+        )
 
     @cli.register_custom_action("ProjectJob")
     @exc.on_http_error(exc.GitlabGetError)
@@ -154,8 +161,10 @@ class ProjectJob(RefreshMixin, RESTObject):
         streamed: bool = False,
         action: Optional[Callable[..., Any]] = None,
         chunk_size: int = 1024,
+        *,
+        iterator: bool = False,
         **kwargs: Any,
-    ) -> Optional[bytes]:
+    ) -> Optional[Union[bytes, Iterator[Any]]]:
         """Get a single artifact file from within the job's artifacts archive.
 
         Args:
@@ -163,6 +172,8 @@ class ProjectJob(RefreshMixin, RESTObject):
             streamed: If True the data will be processed by chunks of
                 `chunk_size` and each chunk is passed to `action` for
                 treatment
+            iterator: If True directly return the underlying response
+                iterator
             action: Callable responsible of dealing with chunk of
                 data
             chunk_size: Size of each chunk
@@ -175,13 +186,15 @@ class ProjectJob(RefreshMixin, RESTObject):
         Returns:
             The artifacts if `streamed` is False, None otherwise.
         """
-        path = f"{self.manager.path}/{self.get_id()}/artifacts/{path}"
+        path = f"{self.manager.path}/{self.encoded_id}/artifacts/{path}"
         result = self.manager.gitlab.http_get(
             path, streamed=streamed, raw=True, **kwargs
         )
         if TYPE_CHECKING:
             assert isinstance(result, requests.Response)
-        return utils.response_content(result, streamed, action, chunk_size)
+        return utils.response_content(
+            result, streamed, action, chunk_size, iterator=iterator
+        )
 
     @cli.register_custom_action("ProjectJob")
     @exc.on_http_error(exc.GitlabGetError)
@@ -190,6 +203,8 @@ class ProjectJob(RefreshMixin, RESTObject):
         streamed: bool = False,
         action: Optional[Callable[..., Any]] = None,
         chunk_size: int = 1024,
+        *,
+        iterator: bool = False,
         **kwargs: Any,
     ) -> Dict[str, Any]:
         """Get the job trace.
@@ -198,6 +213,8 @@ class ProjectJob(RefreshMixin, RESTObject):
             streamed: If True the data will be processed by chunks of
                 `chunk_size` and each chunk is passed to `action` for
                 treatment
+            iterator: If True directly return the underlying response
+                iterator
             action: Callable responsible of dealing with chunk of
                 data
             chunk_size: Size of each chunk
@@ -210,13 +227,15 @@ class ProjectJob(RefreshMixin, RESTObject):
         Returns:
             The trace
         """
-        path = f"{self.manager.path}/{self.get_id()}/trace"
+        path = f"{self.manager.path}/{self.encoded_id}/trace"
         result = self.manager.gitlab.http_get(
             path, streamed=streamed, raw=True, **kwargs
         )
         if TYPE_CHECKING:
             assert isinstance(result, requests.Response)
-        return_value = utils.response_content(result, streamed, action, chunk_size)
+        return_value = utils.response_content(
+            result, streamed, action, chunk_size, iterator=iterator
+        )
         if TYPE_CHECKING:
             assert isinstance(return_value, dict)
         return return_value
@@ -226,6 +245,8 @@ class ProjectJobManager(RetrieveMixin, RESTManager):
     _path = "/projects/{project_id}/jobs"
     _obj_cls = ProjectJob
     _from_parent_attrs = {"project_id": "id"}
+    _list_filters = ("scope",)
+    _types = {"scope": ArrayAttribute}
 
     def get(self, id: Union[str, int], lazy: bool = False, **kwargs: Any) -> ProjectJob:
         return cast(ProjectJob, super().get(id=id, lazy=lazy, **kwargs))
