@@ -1,15 +1,31 @@
 import logging
 import time
+from typing import Optional, TYPE_CHECKING
 
 import pytest
 
+import gitlab
 import gitlab.base
+import gitlab.exceptions
 
 SLEEP_INTERVAL = 0.5
 TIMEOUT = 60  # seconds before timeout will occur
 MAX_ITERATIONS = int(TIMEOUT / SLEEP_INTERVAL)
 
 
+def get_gitlab_plan(gl: gitlab.Gitlab) -> Optional[str]:
+    """Determine the license available on the GitLab instance"""
+    try:
+        license = gl.get_license()
+    except gitlab.exceptions.GitlabLicenseError:
+        # Without a license we assume only Free features are available
+        return None
+
+    if TYPE_CHECKING:
+        assert isinstance(license["plan"], str)
+    return license["plan"]
+
+
 def safe_delete(
     object: gitlab.base.RESTObject,
     *,
@@ -20,7 +36,7 @@ def safe_delete(
     manager = object.manager
     for index in range(MAX_ITERATIONS):
         try:
-            object = manager.get(object.get_id())
+            object = manager.get(object.get_id())  # type: ignore[attr-defined]
         except gitlab.exceptions.GitlabGetError:
             return
 
