@@ -8,10 +8,28 @@ import pytest
 import responses
 
 import gitlab
-from gitlab.v4.objects import GroupDescendantGroup, GroupSubgroup
+from gitlab.v4.objects import (
+    GroupDescendantGroup,
+    GroupLDAPGroupLink,
+    GroupSAMLGroupLink,
+    GroupSubgroup,
+)
 from gitlab.v4.objects.projects import GroupProject, SharedProject
 
 content = {"name": "name", "id": 1, "path": "path"}
+ldap_group_links_content = [
+    {
+        "cn": None,
+        "group_access": 40,
+        "provider": "ldapmain",
+        "filter": "(memberOf=cn=some_group,ou=groups,ou=fake_ou,dc=sub_dc,dc=example,dc=tld)",
+    }
+]
+saml_group_links_content = [{"name": "saml-group-1", "access_level": 10}]
+create_saml_group_link_request_body = {
+    "saml_group_name": "saml-group-1",
+    "access_level": 10,
+}
 projects_content = [
     {
         "id": 9,
@@ -216,6 +234,88 @@ def resp_delete_push_rules_group(no_content):
         yield rsps
 
 
+@pytest.fixture
+def resp_list_ldap_group_links(no_content):
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.GET,
+            url="http://localhost/api/v4/groups/1/ldap_group_links",
+            json=ldap_group_links_content,
+            content_type="application/json",
+            status=200,
+        )
+        yield rsps
+
+
+@pytest.fixture
+def resp_list_saml_group_links():
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.GET,
+            url="http://localhost/api/v4/groups/1/saml_group_links",
+            json=saml_group_links_content,
+            content_type="application/json",
+            status=200,
+        )
+        yield rsps
+
+
+@pytest.fixture
+def resp_get_saml_group_link():
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.GET,
+            url="http://localhost/api/v4/groups/1/saml_group_links/saml-group-1",
+            json=saml_group_links_content[0],
+            content_type="application/json",
+            status=200,
+        )
+        yield rsps
+
+
+@pytest.fixture
+def resp_create_saml_group_link():
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.POST,
+            url="http://localhost/api/v4/groups/1/saml_group_links",
+            match=[
+                responses.matchers.json_params_matcher(
+                    create_saml_group_link_request_body
+                )
+            ],
+            json=saml_group_links_content[0],
+            content_type="application/json",
+            status=200,
+        )
+        yield rsps
+
+
+@pytest.fixture
+def resp_delete_saml_group_link(no_content):
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.POST,
+            url="http://localhost/api/v4/groups/1/saml_group_links",
+            match=[
+                responses.matchers.json_params_matcher(
+                    create_saml_group_link_request_body
+                )
+            ],
+            json=saml_group_links_content[0],
+            content_type="application/json",
+            status=200,
+        )
+        rsps.add(
+            method=responses.DELETE,
+            url="http://localhost/api/v4/groups/1/saml_group_links/saml-group-1",
+            json=no_content,
+            content_type="application/json",
+            status=204,
+        )
+        yield rsps
+
+
 def test_get_group(gl, resp_groups):
     data = gl.groups.get(1)
     assert isinstance(data, gitlab.v4.objects.Group)
@@ -261,6 +361,12 @@ def test_list_group_descendant_groups(group, resp_list_subgroups_descendant_grou
     assert descendant_groups[0].path == subgroup_descgroup_content[0]["path"]
 
 
+def test_list_ldap_group_links(group, resp_list_ldap_group_links):
+    ldap_group_links = group.ldap_group_links.list()
+    assert isinstance(ldap_group_links[0], GroupLDAPGroupLink)
+    assert ldap_group_links[0].provider == ldap_group_links_content[0]["provider"]
+
+
 @pytest.mark.skip("GitLab API endpoint not implemented")
 def test_refresh_group_export_status(group, resp_export):
     export = group.exports.create()
@@ -314,3 +420,36 @@ def test_update_group_push_rule(
 def test_delete_group_push_rule(group, resp_delete_push_rules_group):
     pr = group.pushrules.get()
     pr.delete()
+
+
+def test_list_saml_group_links(group, resp_list_saml_group_links):
+    saml_group_links = group.saml_group_links.list()
+    assert isinstance(saml_group_links[0], GroupSAMLGroupLink)
+    assert saml_group_links[0].name == saml_group_links_content[0]["name"]
+    assert (
+        saml_group_links[0].access_level == saml_group_links_content[0]["access_level"]
+    )
+
+
+def test_get_saml_group_link(group, resp_get_saml_group_link):
+    saml_group_link = group.saml_group_links.get("saml-group-1")
+    assert isinstance(saml_group_link, GroupSAMLGroupLink)
+    assert saml_group_link.name == saml_group_links_content[0]["name"]
+    assert saml_group_link.access_level == saml_group_links_content[0]["access_level"]
+
+
+def test_create_saml_group_link(group, resp_create_saml_group_link):
+    saml_group_link = group.saml_group_links.create(create_saml_group_link_request_body)
+    assert isinstance(saml_group_link, GroupSAMLGroupLink)
+    assert (
+        saml_group_link.name == create_saml_group_link_request_body["saml_group_name"]
+    )
+    assert (
+        saml_group_link.access_level
+        == create_saml_group_link_request_body["access_level"]
+    )
+
+
+def test_delete_saml_group_link(group, resp_delete_saml_group_link):
+    saml_group_link = group.saml_group_links.create(create_saml_group_link_request_body)
+    saml_group_link.delete()
